@@ -2,6 +2,7 @@ import os
 import smartsheet
 from smartsheet.exceptions import ApiError
 
+
 def clean_api_error(test_func):
     def wrapper(*args, **kwargs):
         try:
@@ -13,9 +14,8 @@ def clean_api_error(test_func):
 
 
 class MockApiTestHelper(object):
-    def setup_method(self):
-        os.environ['API_BASE'] = 'http://localhost:8082'
-        self.client = smartsheet.Smartsheet(access_token='abc123')
+    def setup_method(self, method):
+        self.client = smartsheet.Smartsheet(access_token='abc123', api_base='http://localhost:8082')
         self.client.errors_as_exceptions()
 
     def check_error_code(self, exception_info, expected_error_code):
